<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
                      "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"
      xmlns:py="http://genshi.edgewall.org/"
      xmlns:xi="http://www.w3.org/2001/XInclude">

  <xi:include href="master.html" />

<head>
  <title>${user_displayname} Profile</title>
  <link rel="stylesheet" type="text/css" media="screen" href="${profile_css}" />
</head>

<body>
    <div id="userprofile_container">
        <div id="userprofile_avatar_container">
            <img id="userprofile_avatar" src="${user_avatar}" />
        </div>
        <div id="userprofile_info_container">
            <div id="userprofile_title">
                ${user_displayname[1]}
                <div id="userprofile_edit" py:if="is_my_own_profile">
                    <a href="${h.plug_url('userprofile', '/edit')}">edit</a> -
                    <a href="${h.plug_url('userprofile', '/chpasswd')}">change password</a>
                </div>
            </div>
            <div id="userprofile_other_attr">
                <div py:for="attr_name, attr_value in user_data.items()" 
                     id="userprofile_user_attr_${attr_name}" class="userprofile_user_attr">
                    <span class="userprofile_user_attr_title">${attr_value[0]}:</span>
                    <span class="userprofile_user_attr_value">${attr_value[1]}</span>
                </div>
            </div>
            <div py:if="user_partial">
                ${h.call_partial(user_partial, user=user)}
            </div>
        </div>
        <div id="userprofile_end"></div>
    </div>
</body>
</html>
